pub struct RuntimeConfig { /* private fields */ }Expand description
Runtime configuration for all key value stores.
Implementations
Sourceimpl RuntimeConfig
impl RuntimeConfig
Sourcepub fn add_store_manager(
&mut self,
label: String,
store_manager: Arc<dyn StoreManager>,
)
pub fn add_store_manager( &mut self, label: String, store_manager: Arc<dyn StoreManager>, )
Adds a store manager for the store with the given label to the runtime configuration.
If a store manager already exists for the given label, it will be replaced.
Sourcepub fn has_store_manager(&self, label: &str) -> bool
pub fn has_store_manager(&self, label: &str) -> bool
Returns whether a store manager exists for the store with the given label.
Sourcepub fn get_store_manager(&self, label: &str) -> Option<Arc<dyn StoreManager>>
pub fn get_store_manager(&self, label: &str) -> Option<Arc<dyn StoreManager>>
Returns the store manager for the store with the given label.
Sourcepub fn set_max_concurrent_operations(&mut self, max: Option<usize>)
pub fn set_max_concurrent_operations(&mut self, max: Option<usize>)
Sets the maximum number of concurrent in-flight key-value operations for this app.
Sourcepub fn set_wait_timeout(&mut self, wait_timeout: Option<Duration>)
pub fn set_wait_timeout(&mut self, wait_timeout: Option<Duration>)
Sets the timeout used when waiting to acquire a key-value operation permit.
Sourcepub fn max_concurrent_operations(&self) -> Option<usize>
pub fn max_concurrent_operations(&self) -> Option<usize>
Returns the maximum number of concurrent in-flight key-value operations for this app.
Sourcepub fn wait_timeout(&self) -> Option<Duration>
pub fn wait_timeout(&self) -> Option<Duration>
Returns the timeout used when waiting to acquire a key-value operation permit.